package com.chartexample.androiddatachartexample;

import android.app.Activity;
import android.app.Fragment;
import android.graphics.Color;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;

import com.infragistics.controls.CategoryDateTimeXAxis;
import com.infragistics.controls.CategoryXAxis;
import com.infragistics.controls.DataChartView;
import com.infragistics.controls.LineSeries;
import com.infragistics.controls.NumericYAxis;
import com.infragistics.graphics.SolidColorBrush;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.GregorianCalendar;


public class ChartActivity extends Activity {

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_chart);
        if (savedInstanceState == null) {
            getFragmentManager().beginTransaction()
                    .add(R.id.container, new PlaceholderFragment())
                    .commit();
        }
    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.chart, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();
        if (id == R.id.action_settings) {
            return true;
        }
        return super.onOptionsItemSelected(item);
    }

    /**
     * A placeholder fragment containing a simple view.
     */
    public static class PlaceholderFragment extends Fragment {

        public PlaceholderFragment() {
        }

        @Override
        public View onCreateView(LayoutInflater inflater, ViewGroup container,
                Bundle savedInstanceState) {
            View rootView = inflater.inflate(R.layout.fragment_chart, container, false);

            TestData data = new TestData();

            DataChartView chart = new DataChartView(rootView.getContext());
            chart.setHorizontalZoomable(true);
            chart.setVerticalZoomable(true);

            // X Axis
            CategoryDateTimeXAxis xAxis = new CategoryDateTimeXAxis();
            chart.addAxis(xAxis);
            xAxis.setDataSource(data);
            xAxis.setDateTimeMemberPath("Date");
            xAxis.setLabel("Date:D");
            xAxis.setOnFormatLabelListener(new OnAxisDateLabelListener());

            Calendar minCalendar = new GregorianCalendar();
            minCalendar.set(Calendar.YEAR, 2014);
            minCalendar.set(Calendar.MONTH, 6);
            minCalendar.set(Calendar.DAY_OF_MONTH, 30);

            Calendar maxCalendar = new GregorianCalendar();
            maxCalendar.set(Calendar.YEAR, 2014);
            maxCalendar.set(Calendar.MONTH, 8);
            maxCalendar.set(Calendar.DAY_OF_MONTH, 3);

            xAxis.setMinimumValue(minCalendar);
            xAxis.setMaximumValue(maxCalendar);
            xAxis.setInterval(1296000000);

            // Y Axis
            NumericYAxis yAxis = new NumericYAxis();
            chart.addAxis(yAxis);

            LineSeries lineSeries = new LineSeries();
            lineSeries.setXAxis(xAxis);
            lineSeries.setYAxis(yAxis);
            lineSeries.setValueMemberPath("Value");
            lineSeries.setDataSource(data);
            chart.addSeries(lineSeries);

            //////////////////////////////////////////////////////////////////////////////
            // This is the code that needs to be added in order to get horizontal lines
            // We're faking it with LineSeries.

            // this is the data for the MAX horizontal line
            ArrayList<HorizontalLineDataPoint> maxHorizontalLine = new ArrayList<HorizontalLineDataPoint>();
            maxHorizontalLine.add(new HorizontalLineDataPoint(16));
            maxHorizontalLine.add(new HorizontalLineDataPoint(16));

            // this is the data for the MID horizontal line
            ArrayList<HorizontalLineDataPoint> midHorizontalLine = new ArrayList<HorizontalLineDataPoint>();
            midHorizontalLine.add(new HorizontalLineDataPoint(14));
            midHorizontalLine.add(new HorizontalLineDataPoint(14));

            // this is the data for the MIN horizontal line
            ArrayList<HorizontalLineDataPoint> minHorizontalLine = new ArrayList<HorizontalLineDataPoint>();
            minHorizontalLine.add(new HorizontalLineDataPoint(13));
            minHorizontalLine.add(new HorizontalLineDataPoint(13));

            // create an axis for the horizontal lines to use and hide the labels
            CategoryXAxis horizontalLineXAxis = new CategoryXAxis();
            horizontalLineXAxis.setDataSource(maxHorizontalLine);
            horizontalLineXAxis.setLabelsVisible(false);
            chart.addAxis(horizontalLineXAxis);

            // this code is for the MAX horizontal line
            SolidColorBrush red = new SolidColorBrush() ;
            red.setColor(Color.parseColor("#FF0000"));

            LineSeries maxLine = new LineSeries();
            maxLine.setXAxis(horizontalLineXAxis);
            maxLine.setYAxis(yAxis);
            maxLine.setValueMemberPath("Value");
            maxLine.setDataSource(maxHorizontalLine);
            maxLine.setBrush(red);
            chart.addSeries(maxLine);

            // this code is for the MID horizontal line
            SolidColorBrush green = new SolidColorBrush() ;
            green.setColor(Color.parseColor("#008000"));

            LineSeries midLine = new LineSeries();
            midLine.setXAxis(horizontalLineXAxis);
            midLine.setYAxis(yAxis);
            midLine.setValueMemberPath("Value");
            midLine.setDataSource(midHorizontalLine);
            midLine.setBrush(green);
            chart.addSeries(midLine);

            // this code is for the MIN horizontal line
            SolidColorBrush orange = new SolidColorBrush() ;
            orange.setColor(Color.parseColor("#FFA500"));

            LineSeries minLine = new LineSeries();
            minLine.setXAxis(horizontalLineXAxis);
            minLine.setYAxis(yAxis);
            minLine.setValueMemberPath("Value");
            minLine.setDataSource(minHorizontalLine);
            minLine.setBrush(orange);
            chart.addSeries(minLine);

            //////////////////////////////////////////////////////////////////////////////

            return (chart);
        }
    }
}
